import React, { useEffect } from 'react';
import { StyleSheet, View, Animated, Easing, Dimensions } from 'react-native';
import LinearGradient from 'react-native-linear-gradient';
const {
  width
} = Dimensions.get('window');
export const SkeletonView = _ref => {
  let {
    style,
    backgroundColor = '#E2E9ED',
    duration = 1000,
    highlightColor
  } = _ref;
  const Styles = StyleSheet.create({
    DefaultStyle: {
      overflow: 'hidden',
      backgroundColor: backgroundColor
    }
  });
  return /*#__PURE__*/React.createElement(View, {
    style: [style, Styles.DefaultStyle]
  }, /*#__PURE__*/React.createElement(SkeletonAnimation, {
    duration: duration,
    highlightColor: highlightColor,
    backgroundColor: backgroundColor
  }));
};

const SkeletonAnimation = _ref2 => {
  let {
    backgroundColor = '#E2E9ED',
    highlightColor = '#D9E0E3',
    duration = 1000
  } = _ref2;
  const animatedValue = new Animated.Value(0);
  useEffect(() => {
    Animated.loop(Animated.timing(animatedValue, {
      toValue: 1,
      duration: duration,
      easing: Easing.linear,
      useNativeDriver: true
    })).start();
  });
  const translateX = animatedValue.interpolate({
    inputRange: [0, 1],
    outputRange: [-width, width]
  });
  return /*#__PURE__*/React.createElement(View, {
    style: styles.Wrapper
  }, /*#__PURE__*/React.createElement(Animated.View, {
    style: [styles.DefaultSize, {
      transform: [{
        translateX: translateX
      }]
    }]
  }, /*#__PURE__*/React.createElement(LinearGradient, {
    colors: [backgroundColor, highlightColor, highlightColor, backgroundColor],
    style: styles.DefaultSize,
    start: {
      x: 0,
      y: 0
    },
    end: {
      x: 1,
      y: 0
    }
  })));
};

const styles = StyleSheet.create({
  Wrapper: {
    width: '100%',
    height: '100%'
  },
  DefaultSize: {
    width: '100%',
    height: '100%'
  }
});
//# sourceMappingURL=SkeletonView.js.map